package cn.com.ty.lift.enterprise.custom.controller;

import cn.com.ty.lift.enterprise.custom.dao.entity.PropertyCompany;
import cn.com.ty.lift.enterprise.custom.service.impl.PropertyCompanyServiceImpl;
import cn.com.xwy.boot.web.dto.RestResponse;
import lombok.AllArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.time.LocalDateTime;

@RestController
@RequestMapping("/property-company")
@AllArgsConstructor
/**
 * @author wang-hai-cheng
 * @date 2019/11/27
 * @description
 * 客户接口(物业公司)(甲方公司) 前端控制器
 */
public class PropertyCompanyController {
    private final PropertyCompanyServiceImpl propertyCompanyService;

    @GetMapping("/list")
    /**
     * @description id顺序+分页客户列表
     * @date 2019/11/27 11:33
     * @param [pageNum, pageSize]
     * @return cn.com.xwy.boot.web.dto.RestResponse
     */
    public RestResponse propertyCompanies(@RequestParam Long mtCompanyId,@RequestParam Integer pageNum, @RequestParam Integer pageSize) {
        return propertyCompanyService.propertyCompanyListResponse(mtCompanyId,pageNum, pageSize);
    }

    @GetMapping("/{id}")
    /**
     * @description 根据id获取客户详细信息
     * @date 2019/11/27 11:36
     * @param [id]
     * @return cn.com.xwy.boot.web.dto.RestResponse
     */
    public RestResponse propertyCompany(@PathVariable int id) {
        PropertyCompany byId = propertyCompanyService.getById(id);
        if (byId != null) {
            return RestResponse.ok(byId, "查询成功");
        } else {
            return RestResponse.ok(null, "无数据");
        }
    }

    @GetMapping("/list/name")
    /**
     * @description 根据客户名称分页获取客户列表
     * @date 2019/11/27 11:37
     * @param [name, mtCompanyId, current, size]
     * @return cn.com.xwy.boot.web.dto.RestResponse
     */
    public RestResponse propertyCompaniesFromName(@RequestParam String name,@RequestParam Long mtCompanyId, @RequestParam Integer pageNum, @RequestParam Integer pageSize) {
        return propertyCompanyService.propertyCompaniesFromRowName(mtCompanyId,pageNum, pageSize, "name", name);
    }

    @GetMapping("/list/address")
    /**
     * @description 根据客户地址分页获取客户列表
     * @date 2019/11/27 11:38
     * @param [address, mtCompanyId, current, size]
     * @return cn.com.xwy.boot.web.dto.RestResponse
     */
    public RestResponse propertyCompaniesFromAddress(@RequestParam String address,@RequestParam Long mtCompanyId, @RequestParam Integer pageNum, @RequestParam Integer pageSize) {
        return propertyCompanyService.propertyCompaniesFromRowName(mtCompanyId,pageNum, pageSize, "address", address);
    }

    @GetMapping("/list/phone")
    /**
     * @description 根据客户电话分页获取客户列表
     * @date 2019/11/27 11:39
     * @param [phone, mtCompanyId, current, size]
     * @return cn.com.xwy.boot.web.dto.RestResponse
     */
    public RestResponse propertyCompaniesFromPhone(@RequestParam String phone, @RequestParam Long mtCompanyId,@RequestParam Integer pageNum, @RequestParam Integer pageSize) {
        return propertyCompanyService.propertyCompaniesFromRowName(mtCompanyId,pageNum, pageSize, "telephone", phone);
    }

    @PostMapping("/add")
    /**
     * @description 新增客户
     * @date 2019/11/27 11:45
     * @param [propertyCompany]
     * @return cn.com.xwy.boot.web.dto.RestResponse
     */
    public RestResponse add(@RequestBody PropertyCompany propertyCompany) {
        //service层判断了是否有相同名称的name
        propertyCompany.setCreateDate(LocalDateTime.now());
        return RestResponse.ok(null, propertyCompanyService.savePropertyCompany(propertyCompany));
    }

    @PostMapping("/update")
    /**
     * @description 更新客户信息
     * @date 2019/11/27 11:45
     * @param [propertyCompany]
     * @return cn.com.xwy.boot.web.dto.RestResponse
     */
    public RestResponse update(@RequestBody PropertyCompany propertyCompany) {
        if (propertyCompanyService.updateById(propertyCompany)) {
            return RestResponse.ok(null, "更新成功");
        } else {
            return RestResponse.ok(null, "更新失败");
        }
    }

    @GetMapping("/delete/{id}")
    /**
     * @description RestResponse
     * @date 2019/11/27 11:46
     * @param [id]
     * @return cn.com.xwy.boot.web.dto.RestResponse
     */
    public RestResponse delete(@PathVariable int id) {

        //判断维保电梯台数是否为0
        //判断维保电梯台数是否为0
        //判断维保电梯台数是否为0
        //判断维保电梯台数是否为0
        //判断维保电梯台数是否为0
        //判断维保电梯台数是否为0
        //判断维保电梯台数是否为0
        //判断维保电梯台数是否为0
        //判断维保电梯台数是否为0
        //判断维保电梯台数是否为0
        //判断维保电梯台数是否为0
        //也就是客户公司创建的所有项目的总电梯的在保电梯是否为0

        return RestResponse.ok(null, propertyCompanyService.delete(id));
    }

    @GetMapping("/list/current")
    public RestResponse currentProject(@RequestParam Long id) {
    //分页查询正在服务的项目列表
    //分页查询正在服务的项目列表
    //分页查询正在服务的项目列表
    //分页查询正在服务的项目列表
    //分页查询正在服务的项目列表
        return RestResponse.ok(null, "待实现");
    }

    @GetMapping("/list/previous")
    public RestResponse previousProject(@RequestParam Long id) {
    //分页查询曾经服务的项目列表
    //分页查询曾经服务的项目列表
    //分页查询曾经服务的项目列表
    //分页查询曾经服务的项目列表
    //分页查询曾经服务的项目列表
        return RestResponse.ok(null, "待实现");
    }
}